@@ -302,6 +302,7 @@ class GatewayCliCommands(cmd.Cmd):
             - iterations=Inf
             - update_rate=1 # period to print status if no message is acquired
             - show_events=False # will display answers as well
+            - machine_format=False # If yes, format is formatted to machine readable format.
 
         Returns:
             Prints messages to console
@@ -318,6 +319,7 @@ class GatewayCliCommands(cmd.Cmd):
             update_rate=dict(type=int, default=1),
             show_events=dict(type=bool, default=False),
             silent=dict(type=bool, default=True),
+            machine_format=dict(type=bool, default=False),
         )
 
         args = self.retrieve_args(line, options)
@@ -332,6 +334,7 @@ class GatewayCliCommands(cmd.Cmd):
             gw_id = kwargs.get("gw_id", None)
             sink_id = kwargs.get("sink_id", None)
             show_events = kwargs.get("show_events", None)
+            machine_format = kwargs.get("machine_format", None)
 
             def print_on_match(message):
                 if (
@@ -346,27 +349,30 @@ class GatewayCliCommands(cmd.Cmd):
                         message, "destination_endpoint", destination_endpoint
                     )
                 ):
-                    address_str = (
-                        "nw:{}/{}/{}/node:{} sendp:{}".format(
-                            str(message.network_id),
-                            message.gw_id,
-                            message.sink_id,
-                            message.source_address,
-                            message.source_endpoint,
+                    if machine_format is True:
+                        print(message)
+                    else:
+                        address_str = (
+                            "nw:{}/{}/{}/node:{} sendp:{}".format(
+                                message.network_id,
+                                message.gw_id,
+                                message.sink_id,
+                                message.source_address,
+                                message.source_endpoint,
+                            )
+                        ).ljust(60)
+                        travel_time_str = str(
+                            "travel time: {}".format(message.travel_time_ms)
+                        ).ljust(19)
+                        data_str = str(
+                            "data: {}".format(message.data_payload.hex())
                         )
-                    ).ljust(50)
-                    travel_time_str = str(
-                        "travel time: {}".format(message.travel_time_ms)
-                    ).ljust(19)
-                    data_str = str(
-                        "data: {}".format(message.data_payload.hex())
-                    )
 
-                    print(
-                        "{} {} {}".format(
-                            address_str, travel_time_str, data_str
+                        print(
+                            "{} {} {}".format(
+                                address_str, travel_time_str, data_str
+                            )
                         )
-                    )
 
             msgs = cli.get_messages_from_data_queue()
             if msgs is not None:
@@ -459,8 +465,11 @@ class GatewayCliCommands(cmd.Cmd):
         )
         self.request_queue.put(message)
         response = self.wait_for_answer(gateway_device_id, message)
-        if response.res == GatewayResultCode.GW_RES_OK:
-            ret = response.configs
+        if response is not None:
+            if response.res == GatewayResultCode.GW_RES_OK:
+                ret = response.configs
+            else:
+                pass
         else:
             pass
         return ret
@@ -478,11 +487,13 @@ class GatewayCliCommands(cmd.Cmd):
 
     def _lookup_node_address(self, gateway_device_id, sink_id):
         ret = None
-        gwConfig = self._get_gateway_configuration(gateway_device_id)
-        if gwConfig is not None:
-            sinkConfig = self._filter_gateway_configuration(gwConfig, sink_id)
-            if sinkConfig is not None:
-                ret = sinkConfig["node_address"]
+        gw_config = self._get_gateway_configuration(gateway_device_id)
+        if gw_config is not None:
+            sink_config = self._filter_gateway_configuration(
+                gw_config, sink_id
+            )
+            if sink_config is not None:
+                ret = sink_config["node_address"]
         return ret
 
     def do_set_sink(self, line):
@@ -598,23 +609,26 @@ class GatewayCliCommands(cmd.Cmd):
         offline_gws: int = 0
         gateways = list(self.device_manager.gateways)
         for gateway in gateways:
+
             if gateway.state.value == GatewayState.OFFLINE.value:
                 message = self.mqtt_topics.event_message(
                     "clear", **dict(gw_id=gateway.device_id)
                 )
+
                 message["data"].Clear()
                 message["data"] = message["data"].SerializeToString()
                 message["retain"] = True
 
                 print("sending clear for gateway {}".format(message))
 
-                # remove from state
-                self.device_manager.remove(gateway.device_id)
-                self.notify()
-
                 self.request_queue.put(message)
                 offline_gws += 1
-                continue
+
+                # remove from state
+                if gateway.device_id in self.device_manager.gateways:
+                    self.device_manager.remove(gateway.device_id)
+                    self.notify()
+
         if offline_gws > 0:
             print("Command ok. Offline GW count was {}.".format(offline_gws))
         else:
@@ -844,9 +858,14 @@ class GatewayCliCommands(cmd.Cmd):
             )
             configurations = self._get_gateway_configuration(gateway.device_id)
 
-            for config in configurations:
-                if config is not None:
-                    print(self._format_gateway_configuration_to_string(config))
+            if configurations is not None:
+                for config in configurations:
+                    if config is not None:
+                        print(
+                            self._format_gateway_configuration_to_string(
+                                config
+                            )
+                        )
 
     def _format_gateway_configuration_to_string(self, config: object) -> str:
         ret: str = ""
@@ -951,9 +970,9 @@ class GatewayCliCommands(cmd.Cmd):
             set_app_config  argument=value
 
         Arguments:
-            - seq=1  # the sequence number - must be higher than the current one.
-            - data=001100 # payloady in hex string or plain string.
-            - interval=60 # a valid diagnostic interval (by default 60).
+            - app_config_seq=1  # the sequence number - must be higher than the current one.
+            - app_config_data=001100 # payload in hex string or plain string.
+            - app_config_diag=60 # a valid diagnostic interval (by default 60).
 
         Returns:
             Prints result of the request to console.
@@ -1681,19 +1700,21 @@ class GatewayCliCommands(cmd.Cmd):
                             ):
                                 data_msgs = self.get_messages_from_data_queue()
 
-                                for data_msg in data_msgs:
-                                    if data_msg is not None:
-                                        if (
-                                            self.__scratchpad_update_only_nodes_h(
-                                                data_msg, responded_nodes_ok
-                                            )
-                                            is True
-                                        ):
-                                            last_msg_received_time = (
-                                                perf_counter()
-                                            )
+                                if data_msgs is not None:
+                                    for data_msg in data_msgs:
+                                        if data_msg is not None:
+                                            if (
+                                                self.__scratchpad_update_only_nodes_h(
+                                                    data_msg,
+                                                    responded_nodes_ok,
+                                                )
+                                                is True
+                                            ):
+                                                last_msg_received_time = (
+                                                    perf_counter()
+                                                )
 
-                                if data_msgs is None:
+                                else:
                                     default_sleep_time: float = 0.1
                                     sleep(default_sleep_time)
 
